.. module:: hubugs.template

Template
========

.. note::

   The documentation in this section is aimed at people wishing to contribute
   to :mod:`hubugs`, and can be skipped if you are simply using the tool from
   the command line.

.. autofunction:: get_template

Jinja filter support
--------------------

.. autofunction:: jinja_filter
.. autofunction:: colourise
.. autofunction:: highlight
.. autofunction:: html2text

User interface support
----------------------

.. autofunction:: display_bugs
.. autofunction:: edit_text
